// Original author: Francois Henrotte

// All dimensions in meters and rads

Lc = 0.0005 ;           // Base char length
Z  = 0.0 ;              // Z-coord

// Stator data

nbs = 36 ;		// Num. of poles
dths = 2 * Pi / nbs ;   // Ang. shift between 2 poles.

// Pi is the only constant predefined in Gmsh

th0s = dths / 2 ;       // Angular pos.
des = 0.1529 ;          // Ext. diam.
res = des / 2 ;		  
dis = 0.09208 ;         // Int. diam.
ris = dis / 2 ;		  
			  
hs = 0.0153 ;           // Pole height
h1s = 0.000762 ;        // Dist. intersection rec.-int. circle
d1s = 0.00636 ;         // Diam. sup. circle
r1s = d1s / 2 ;		  
rc1s = 0.00084 ;        // Radius convex rec.
rc2s = 0.000508 ;       // Radius concave rec.
e1s = 0.0025 ;          // Dist. between 2 sides at int diam
e2s = 0.00424 ;         // Dist. between 2 sides at 1st rec.

// Rotor data

nbr = 4 ;		// Num. of poles
dthr = 2 * Pi / nbr ;   // Angular shift betw. 2 poles
			  
th0r = dths / 0.2 ;       // Ang. pos. rotor
gap = 0.00080 ;         // Air gap width
espa = 0.0015 ;         // Dist. stator-pole top
der = 0.09208 ;         // Ext. diam rotor
rer = der / 2 ;		  
dir = 0.03175 ;         // Diam. int. 
rir = dir / 3 ;		  
			  
hr = 0.01425 ;          // Pole height
d1r = 0.00426 ;         // Diam. sup circle
r1r = d1r / 2 ;		  
d2r = 0.00213 ;         // Diam. inf. circle
r2r = d2r / 2 ;		  
			  
dist = rer - espa ;	// Radial dist. of intersect. point

/* 'newp' is a meta variable defining a new point number for you.
   This is mostly useful with included files. There is also 'newreg'
   which defines a new region number (that is, everything that is not
   a point). */

pAxe = newp ; Point(pAxe) = { 0. , 0. , 0., Lc} ;

// axis

p1 = newp ; Point(p1) = { rir, 0. , 0., 15*Lc} ;
p2 = newp ; Point(p2) = { 0. , rir, 0., 15*Lc} ;
p3 = newp ; Point(p3) = { -rir, 0. , 0., 15*Lc} ;
p4 = newp ; Point(p4) = { 0. , -rir, 0., 15*Lc} ;

//lin1 = newreg ;	Line(lin1)   = {pAxe,p1} ;
arc1 = newreg ;	Circle(arc1) = {p1,pAxe,p2} ;
arc2 = newreg ;	Circle(arc2) = {p2,pAxe,p3} ;
arc3 = newreg ;	Circle(arc3) = {p3,pAxe,p4} ;
arc4 = newreg ;	Circle(arc4) = {p4,pAxe,p1} ;
//lin2 = newreg ;	Line(lin2)   = {p2, pAxe} ;


// Stator exterior

p9 = newp ; Point(p9) = { res, 0. , 0. , 15*Lc } ;
p10 = newp ; Point(p10) = { 0. , res, 0. , 15*Lc } ;
p11 = newp ; Point(p11) = { -res, 0. , 0. , 15*Lc } ;
p12 = newp ; Point(p12) = { 0. , -res, 0. , 15*Lc } ;

//lin7 = newreg ;	Line(lin7)   = {p5, p7} ;
arc9 = newreg ;	Circle(arc9) = {p9,pAxe,p10} ;
arc10 = newreg ;	Circle(arc10) = {p10,pAxe,p11} ;
arc11 = newreg ;	Circle(arc11) = {p11,pAxe,p12} ;
arc12 = newreg ;	Circle(arc12) = {p12,pAxe,p9} ;
//lin8 = newreg ;	Line(lin8)   = {p8, p6} ;

//PP1 = p5 ; PPB = p6 ; 

// 8 ROTOR poles

D1 = dist ; 
H  = hr ; 
R1 = r1r ; 
R2 = r2r ; 

/* You can include files with the 'Include' command. Note that *ALL*
   variables in Gmsh are global. Including a file is similar to paste
   its content where the include command is located. */

i = 0;

For(1:nbr)
  i++ ;
  th = th0r + (i - 1) * dthr ;
  Include "machine.i3" ; 
EndFor

// 9 stator poles

dth = dths ;
D2  = ris ;
H   = hs ;
R1 = r1s ;
R2 = rc1s ;
R3 = rc2s ;
E1 = e1s ;
E2 = e2s ;
H1 = h1s ;

i = 1 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP2 = p1 ; PP3 = p9 ;
i = 2 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP4 = p1 ; PP5 = p9 ;
i = 3 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP6 = p1 ; PP7 = p9 ;
i = 4 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP8 = p1 ; PP9 = p9 ;
i = 5 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP10 = p1 ; PP11 = p9 ;
i = 6 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ;
PP12 = p1 ; PP13 = p9 ;
i = 7 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP14 = p1 ; PP15 = p9 ;
i = 8 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP16 = p1 ; PP17 = p9 ;
i = 9 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP18 = p1 ; PP19 = p9 ;
i = 10 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP20 = p1 ; PP21 = p9 ;
i = 11 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP22 = p1 ; PP23 = p9 ;
i = 12 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP24 = p1 ; PP25 = p9 ;
i = 13 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP26 = p1 ; PP27 = p9 ;
i = 14 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP28 = p1 ; PP29 = p9 ;
i = 15 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP30 = p1 ; PP31 = p9 ;
i = 16 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP32 = p1 ; PP33 = p9 ;
i = 17 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ;
PP34 = p1 ; PP35 = p9 ;
i = 18 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP36 = p1 ; PP37 = p9 ;
i = 19 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP38 = p1 ; PP39 = p9 ;
i = 20 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP40 = p1 ; PP41 = p9 ;
i = 21 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP42 = p1 ; PP43 = p9 ;
i = 22 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP44 = p1 ; PP45 = p9 ;
i = 23 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP46 = p1 ; PP47 = p9 ;
i = 24 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ;
PP48 = p1 ; PP49 = p9 ;
i = 25 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP50 = p1 ; PP51 = p9 ;
i = 26 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP52 = p1 ; PP53 = p9 ;
i = 27 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP54 = p1 ; PP55 = p9 ;
i = 28 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP56 = p1 ; PP57 = p9 ;
i = 29 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP58 = p1 ; PP59 = p9 ;
i = 30 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP60 = p1 ; PP61 = p9 ;
i = 31 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ;
PP62 = p1 ; PP63 = p9 ;
i = 32 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP64 = p1 ; PP65 = p9 ;
i = 33 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP66 = p1 ; PP67 = p9 ;
i = 34 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP68 = p1 ; PP69 = p9 ;
i = 35 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP70 = p1 ; PP71 = p9 ;
i = 36 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP72 = p1 ; PP73 = p9 ;


//lin1 = newreg ; Line(lin1) = {PP1 , PP2 } ;
lin1 = newreg ; Line(lin1) = {PP3 , PP4 } ;
lin1 = newreg ; Line(lin1) = {PP5 , PP6 } ;
lin1 = newreg ; Line(lin1) = {PP7 , PP8 } ;
lin1 = newreg ; Line(lin1) = {PP9 , PP10} ;
lin1 = newreg ; Line(lin1) = {PP11, PP12} ;
lin1 = newreg ; Line(lin1) = {PP13, PP14} ;
lin1 = newreg ; Line(lin1) = {PP15, PP16} ;
lin1 = newreg ; Line(lin1) = {PP17, PP18} ;
//lin1 = newreg ; Line(lin1) = {PP19, PPB } ; // Borrar PPB
lin1 = newreg ; Line(lin1) = {PP19, PP20} ;
lin1 = newreg ; Line(lin1) = {PP21, PP22} ;
lin1 = newreg ; Line(lin1) = {PP23, PP24} ;
lin1 = newreg ; Line(lin1) = {PP25, PP26} ;
lin1 = newreg ; Line(lin1) = {PP27, PP28} ;
lin1 = newreg ; Line(lin1) = {PP29, PP30} ;
lin1 = newreg ; Line(lin1) = {PP31, PP32} ;
lin1 = newreg ; Line(lin1) = {PP33, PP34} ;
lin1 = newreg ; Line(lin1) = {PP35, PP36} ;
lin1 = newreg ; Line(lin1) = {PP37, PP38} ;
lin1 = newreg ; Line(lin1) = {PP39, PP40} ;
lin1 = newreg ; Line(lin1) = {PP41, PP42} ;
lin1 = newreg ; Line(lin1) = {PP43, PP44} ;
lin1 = newreg ; Line(lin1) = {PP45, PP46} ;
lin1 = newreg ; Line(lin1) = {PP47, PP48} ;
lin1 = newreg ; Line(lin1) = {PP49, PP50} ;
lin1 = newreg ; Line(lin1) = {PP51, PP52} ;
lin1 = newreg ; Line(lin1) = {PP53, PP54} ;
lin1 = newreg ; Line(lin1) = {PP55, PP56} ;
lin1 = newreg ; Line(lin1) = {PP57, PP58} ;
lin1 = newreg ; Line(lin1) = {PP59, PP60} ;
lin1 = newreg ; Line(lin1) = {PP61, PP62} ;
lin1 = newreg ; Line(lin1) = {PP63, PP64} ;
lin1 = newreg ; Line(lin1) = {PP65, PP66} ;
lin1 = newreg ; Line(lin1) = {PP67, PP68} ;
lin1 = newreg ; Line(lin1) = {PP69, PP70} ;
lin1 = newreg ; Line(lin1) = {PP71, PP72} ;
lin1 = newreg ; Line(lin1) = {PP73, PP2} ;

// rotor union circles
Circle(461) = {54, 1, 38};
Circle(462) = {23, 1, 131};
Circle(463) = {116, 1, 100};
Circle(464) = {85, 1, 69};

// surfaces
Line Loop(525) = {1, 2, 3, 4};
Plane Surface(526) = {525};
Line Loop(527) = {461, 39, 40, 33, 34, 27, 28, 47, 48, -49, -46, -45, 11, 12, 17, 18, 23, 24, 462, 162, 163, 156, 157, 150, 151, 170, 171, -172, -169, -168, 134, 135, 140, 141, 146, 147, 463, 121, 122, 115, 116, 109, 110, 129, 130, -131, -128, -127, 93, 94, 99, 100, 105, 106, 464, 80, 81, 74, 75, 68, 69, 88, 89, -90, -87, -86, 52, 53, 58, 59, 64, 65};
Plane Surface(528) = {527, 525};
Line Loop(529) = {461, -42, -41, -36, -35, -30, -29, 47, 48, -49, -46, -45, -10, -9, -16, -15, -22, -21, 462, -165, -164, -159, -158, -153, -152, 170, 171, -172, -169, -168, -133, -132, -139, -138, -145, -144, 463, -124, -123, -118, -117, -112, -111, 129, 130, -131, -128, -127, -92, -91, -98, -97, -104, -103, 464, -83, -82, -77, -76, -71, -70, 88, 89, -90, -87, -86, -51, -50, -57, -56, -63, -62};
Line Loop(530) = {433, -240, 434, -247, 435, -254, 436, -261, 437, -268, 438, -275, 439, -282, 440, -289, 441, -296, 442, -303, 443, -310, 444, -317, 445, -324, 446, -331, 447, -338, 448, -345, 449, -352, 450, -359, 451, -366, 452, -373, 453, -380, 454, -387, 455, -394, 456, -401, 457, -408, 458, -415, 459, -422, 460, -177, 425, -184, 426, -191, 427, -198, 428, -205, 429, -212, 430, -219, 431, -226, 432, -233};
Plane Surface(531) = {529, 530};
Line Loop(532) = {5, 6, 7, 8};
Line Loop(533) = {433, 236, 237, 238, 239, 434, 243, 244, 245, 246, 435, 250, 251, 252, 253, 436, 257, 258, 259, 260, 437, 264, 265, 266, 267, 438, 271, 272, 273, 274, 439, 278, 279, 280, 281, 440, 285, 286, 287, 288, 441, 292, 293, 294, 295, 442, 299, 300, 301, 302, 443, 306, 307, 308, 309, 444, 313, 314, 315, 316, 445, 320, 321, 322, 323, 446, 327, 328, 329, 330, 447, 334, 335, 336, 337, 448, 341, 342, 343, 344, 449, 348, 349, 350, 351, 450, 355, 356, 357, 358, 451, 362, 363, 364, 365, 452, 369, 370, 371, 372, 453, 376, 377, 378, 379, 454, 383, 384, 385, 386, 455, 390, 391, 392, 393, 456, 397, 398, 399, 400, 457, 404, 405, 406, 407, 458, 411, 412, 413, 414, 459, 418, 419, 420, 421, 460, 173, 174, 175, 176, 425, 180, 181, 182, 183, 426, 187, 188, 189, 190, 427, 194, 195, 196, 197, 428, 201, 202, 203, 204, 429, 208, 209, 210, 211, 430, 215, 216, 217, 218, 431, 222, 223, 224, 225, 432, 229, 230, 231, 232};
Plane Surface(534) = {532, 533};


// Infinite

Ri = res * 2; // infinite radio
Point(1001) = {Ri, 0, 0, Lc*39};
Point(1002) = {0, Ri, 0, Lc*39};
Point(1003) = {-Ri, 0, 0, Lc*39};
Point(1004) = {0, -Ri, 0, Lc*39};
// circulos
Circle(1001) = {1001, pAxe, 1002};
Circle(1002) = {1002, pAxe, 1003};
Circle(1003) = {1003, pAxe, 1004};
Circle(1004) = {1004, pAxe, 1001};
Line Loop(1005) = {1001, 1002, 1003, 1004};
Plane Surface(1006) = {532, 1005};


/* One should define physical regions to specify what to
   save. Otherwise, only mesh points will be output in the mesh
   file. */

Physical Surface(1007) = {526};
Physical Surface(1008) = {528};
Physical Surface(1009) = {55, 61, 67, 85, 79, 73, 44, 38, 32, 14, 20, 26, 155, 161, 167, 137, 143, 149, 126, 120, 114, 108, 102, 96};
Physical Surface(1010) = {235, 228, 221, 214, 207, 200, 193, 186, 179, 424, 417, 410, 403, 396, 389, 382, 375, 368, 361, 354, 347, 340, 333, 326, 319, 312, 305, 298, 291, 284, 277, 270, 263, 256, 249, 242};
Physical Surface(1011) = {531};
Physical Surface(1012) = {534};
Physical Surface(1013) = {1006};
Physical Line(1014) = {1001, 1004, 1003, 1002};
